Crate netgauze_bmp_pkt

Crate netgauze_bmp_pkt 

Modules

iana
Contains BMP codes that are registered at IANA BGP Monitoring Protocol (BMP) Parameters
v3
v4
wire
Serialize/Deserialize BMP wire protocol

Structs

CounterU32
A non-negative integer that monotonically increases until it reaches a maximum value, when it wraps around and starts increasing again from 0.
GaugeU64
Non-negative integer that may increase or decrease, but shall never exceed a maximum value, nor fall below a minimum one. The maximum value cannot be greater than 2^64-1 (18446744073709551615 decimal), and the minimum value cannot be smaller than 0. The value has its maximum value whenever the information being modeled is greater than or equal to its maximum value, and has its minimum value whenever the information being modeled is smaller than or equal to its minimum value. If the information being modeled subsequently decreases below the maximum value (or increases above the minimum value), the 64-bit Gauge also decreases (or increases).
PeerHeader
The per-peer header follows the common header for most BMP messages. The rest of the data in a BMP message is dependent on the Message Type field in the common header.
PeerKey
PeerKey is used to identify a BMP peer. This key is unique only to the BMP session.

Enums

BmpMessage
BmpPeerType
Identifies the type of peer, along with the type specific flags Flags: