Non-negative integer that may increase or decrease,
but shall never exceed a maximum value, nor fall below a minimum one.
The maximum value cannot be greater than 2^64-1 (18446744073709551615
decimal), and the minimum value cannot be smaller than 0. The value
has its maximum value whenever the information being modeled is
greater than or equal to its maximum value, and has its minimum value
whenever the information being modeled is smaller than or equal to
its minimum value. If the information being modeled subsequently
decreases below the maximum value (or increases above the minimum
value), the 64-bit Gauge also decreases (or increases).
The per-peer header follows the common header for most BMP messages.
The rest of the data in a BMP message is dependent on the Message
Type field in the common header.